email

# XMLRésuméLibrary: User Guide

docpath | Element Reference | emphasis

## Name

email — An e-mail address

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `email` element specifies a single e-mail address.

### Parents

`email` may be contained in these elements: `contact`

## See Also

`fax`, `instantMessage`, `pager`, `url`.

## Examples

    <contact>
      <email>john@johnny.bob</email>
      <phone>555-555-1212</phone>
    </contact>

docpath | Element Reference | emphasis